@@ -15,9 +15,10 @@ class UIHandler(Handler):
     default = 'shell'
 
     @classmethod
-    def setup(cls, name=None):
-        def ui(uitype='shell'):
-            """Instead of instantiating the handler, return a new instance of
-            the chosen UI object."""
-            return UI.family_member('name', uitype)()
-        return ui
+    def setup(cls, uitype):
+        return UI.family_member('name', uitype)()
+
+    @classmethod
+    def fake(cls, val=None):
+        """Use mock_keys"""
+        return
